@@ -16,8 +16,8 @@ loop[1] = """\
         return np.FLOAT(NAN)
     k = nAXIS >> 1
     l = 0
-    r = nAXIS - 1 
-    with nogil:       
+    r = nAXIS - 1
+    with nogil:
         while l < r:
             x = b[k]
             i = l
@@ -34,7 +34,7 @@ loop[1] = """\
                 if i > j: break
             if j < k: l = i
             if k < i: r = j
-    if nAXIS % 2 == 0:        
+    if nAXIS % 2 == 0:
         amax = MINDTYPE
         for i in range(k):
             ai = b[i]
@@ -43,12 +43,12 @@ loop[1] = """\
         return np.FLOAT(0.5 * (b[k] + amax))
     else:
         return np.FLOAT(b[k])
-"""        
+"""
 loop[2] = """\
     if nINDEX1 == 0:
         PyArray_FillWithScalar(y, NAN)
         return y
-    for iINDEX0 in range(nINDEX0): 
+    for iINDEX0 in range(nINDEX0):
         k = nAXIS >> 1
         l = 0
         r = nAXIS - 1
@@ -68,7 +68,7 @@ loop[2] = """\
                 if i > j: break
             if j < k: l = i
             if k < i: r = j
-        if nAXIS % 2 == 0:        
+        if nAXIS % 2 == 0:
             amax = MINDTYPE
             for i in range(k):
                 ai = b[INDEXREPLACE|i|]
@@ -76,7 +76,7 @@ loop[2] = """\
                     amax = ai
             y[INDEXPOP] = 0.5 * (b[INDEXREPLACE|k|] + amax)
         else:
-            y[INDEXPOP] = CASTb[INDEXREPLACE|k|]         
+            y[INDEXPOP] = CASTb[INDEXREPLACE|k|]
     return y
 """
 loop[3] = """\
@@ -104,7 +104,7 @@ loop[3] = """\
                     if i > j: break
                 if j < k: l = i
                 if k < i: r = j
-            if nAXIS % 2 == 0:        
+            if nAXIS % 2 == 0:
                 amax = MINDTYPE
                 for i in range(k):
                     ai = b[INDEXREPLACE|i|]
@@ -112,7 +112,7 @@ loop[3] = """\
                         amax = ai
                 y[INDEXPOP] = 0.5 * (b[INDEXREPLACE|k|] + amax)
             else:
-                y[INDEXPOP] = CASTb[INDEXREPLACE|k|]         
+                y[INDEXPOP] = CASTb[INDEXREPLACE|k|]
     return y
 """
 
@@ -129,7 +129,7 @@ floats['top'] = """
 @cython.wraparound(False)
 def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a):
     "Median of NDIMd array with dtype=DTYPE along axis=AXIS."
-    cdef np.npy_intp i, j = 0, l, r, k 
+    cdef np.npy_intp i, j = 0, l, r, k
     cdef np.DTYPE_t x, tmp, amax, ai
     cdef np.ndarray[np.DTYPE_t, ndim=NDIM] b = PyArray_Copy(a)
 """
@@ -142,7 +142,7 @@ floats['loop'][3] = loop[3].replace('CAST', '')
 # Int dtypes (not axis=None) ------------------------------------------------
 
 ints = deepcopy(floats)
-ints['dtypes'] = INT_DTYPES 
+ints['dtypes'] = INT_DTYPES
 ints['force_output_dtype'] = 'float64'
 ints['loop'] = {}
 ints['loop'][1] = loop[1].replace('FLOAT', 'float64')
@@ -166,13 +166,13 @@ median['slow'] = slow
 median['templates'] = {}
 median['templates']['float'] = floats
 median['templates']['int'] = ints
-median['pyx_file'] = 'func/%sbit/median.pyx'
+median['pyx_file'] = 'func/median.pyx'
 
 median['main'] = '''"median auto-generated from template"
 # Select smallest k elements code used for inner loop of median method:
 # http://projects.scipy.org/numpy/attachment/ticket/1213/quickselect.pyx
 # (C) 2009 Sturla Molden
-# SciPy license 
+# SciPy license
 #
 # From the original C function (code in public domain) in:
 #   Fast median search: an ANSI C implementation
@@ -203,11 +203,11 @@ def median(arr, axis=None):
     y : ndarray
         An array with the same shape as `arr`, except that the specified axis
         has been removed. If `arr` is a 0d array, or if axis is None, a scalar
-        is returned. `float64` return values are used for integer inputs. 
-    
+        is returned. `float64` return values are used for integer inputs.
+
     See also
     --------
-    bottleneck.nanmedian: Median along specified axis ignoring NaNs. 
+    bottleneck.nanmedian: Median along specified axis ignoring NaNs.
 
     Notes
     -----
@@ -226,7 +226,7 @@ def median(arr, axis=None):
     array([ 6.5,  4.5,  2.5])
     >>> bn.median(a, axis=1)
     array([ 7.,  2.])
-    
+
     """
     func, arr = median_selector(arr, axis)
     return func(arr)
@@ -234,7 +234,7 @@ def median(arr, axis=None):
 def median_selector(arr, axis):
     """
     Return median function and array that matches `arr` and `axis`.
-    
+
     Under the hood Bottleneck uses a separate Cython function for each
     combination of ndim, dtype, and axis. A lot of the overhead in
     bn.median() is in checking that `axis` is within range, converting `arr`
@@ -250,7 +250,7 @@ def median_selector(arr, axis):
         Input array. If `arr` is not an array, a conversion is attempted.
     axis : {int, None}
         Axis along which the median is to be computed.
-    
+
     Returns
     -------
     func : function
@@ -266,13 +266,13 @@ def median_selector(arr, axis):
     Create a numpy array:
 
     >>> arr = np.array([1.0, 2.0, 3.0])
-    
+
     Obtain the function needed to determine the median of `arr` along axis=0:
 
     >>> func, a = bn.func.median_selector(arr, axis=0)
     >>> func
     <function median_1d_float64_axis0>
-    
+
     Use the returned function and array to determine the median:
 
     >>> func(a)
@@ -282,7 +282,7 @@ def median_selector(arr, axis):
     cdef np.ndarray a
     if type(arr) is np.ndarray:
         a = arr
-    else:    
+    else:
         a = np.array(arr, copy=False)
     cdef tuple key
     cdef int ndim = PyArray_NDIM(a)
@@ -306,4 +306,4 @@ def median_selector(arr, axis):
             tup = (str(ndim), str(a.dtype), str(axis))
             raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
-'''   
+'''
