@@ -28,7 +28,7 @@ def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a):
 loop = {}
 loop[2] = """\
     if nINDEX1 == 0:
-        msg = "numpy.nanmax raises on a.shape[axis]==0; so Bottleneck does." 
+        msg = "numpy.nanmax raises on a.shape[axis]==0; so Bottleneck does."
         raise ValueError(msg)
     for iINDEX0 in range(nINDEX0):
         amax = MINDTYPE
@@ -38,7 +38,7 @@ loop[2] = """\
             if ai >= amax:
                 amax = ai
                 allnan = 0
-        if allnan == 0:       
+        if allnan == 0:
             y[INDEXPOP] = amax
         else:
             y[INDEXPOP] = NAN
@@ -46,7 +46,7 @@ loop[2] = """\
 """
 loop[3] = """\
     if nINDEX2 == 0:
-        msg = "numpy.nanmax raises on a.shape[axis]==0; so Bottleneck does." 
+        msg = "numpy.nanmax raises on a.shape[axis]==0; so Bottleneck does."
         raise ValueError(msg)
     for iINDEX0 in range(nINDEX0):
         for iINDEX1 in range(nINDEX1):
@@ -57,7 +57,7 @@ loop[3] = """\
                 if ai >= amax:
                     amax = ai
                     allnan = 0
-            if allnan == 0:       
+            if allnan == 0:
                 y[INDEXPOP] = amax
             else:
                 y[INDEXPOP] = NAN
@@ -74,7 +74,7 @@ floats_None['axisNone'] = True
 loop = {}
 loop[1] = """\
     if nINDEX0 == 0:
-        m = "numpy.nanmax raises on a.size==0 and axis=None; Bottleneck too." 
+        m = "numpy.nanmax raises on a.size==0 and axis=None; Bottleneck too."
         raise ValueError(m)
     amax = MINDTYPE
     for iINDEX0 in range(nINDEX0):
@@ -82,14 +82,14 @@ loop[1] = """\
         if ai >= amax:
             amax = ai
             allnan = 0
-    if allnan == 0:       
+    if allnan == 0:
         return np.DTYPE(amax)
     else:
         return np.DTYPE(NAN)
 """
 loop[2] = """\
     if nINDEX0 * nINDEX1 == 0:
-        m = "numpy.nanmax raises on a.size==0 and axis=None; Bottleneck too." 
+        m = "numpy.nanmax raises on a.size==0 and axis=None; Bottleneck too."
         raise ValueError(m)
     amax = MINDTYPE
     for iINDEX0 in range(nINDEX0):
@@ -98,14 +98,14 @@ loop[2] = """\
             if ai >= amax:
                 amax = ai
                 allnan = 0
-    if allnan == 0:       
+    if allnan == 0:
         return np.DTYPE(amax)
     else:
         return np.DTYPE(NAN)
 """
 loop[3] = """\
     if nINDEX0 * nINDEX1 * nINDEX2 == 0:
-        m = "numpy.nanmax raises on a.size==0 and axis=None; Bottleneck too." 
+        m = "numpy.nanmax raises on a.size==0 and axis=None; Bottleneck too."
         raise ValueError(m)
     amax = MINDTYPE
     for iINDEX0 in range(nINDEX0):
@@ -115,7 +115,7 @@ loop[3] = """\
                 if ai >= amax:
                     amax = ai
                     allnan = 0
-    if allnan == 0:       
+    if allnan == 0:
         return np.DTYPE(amax)
     else:
         return np.DTYPE(NAN)
@@ -126,7 +126,7 @@ floats_None['loop'] = loop
 # Int dtypes (not axis=None) ------------------------------------------------
 
 ints = deepcopy(floats)
-ints['dtypes'] = INT_DTYPES 
+ints['dtypes'] = INT_DTYPES
 
 loop = {}
 loop[2] = """\
@@ -161,7 +161,7 @@ ints['loop'] = loop
 
 # Int dtypes (axis=None) ----------------------------------------------------
 
-ints_None = deepcopy(ints) 
+ints_None = deepcopy(ints)
 ints_None['axisNone'] = True
 
 loop = {}
@@ -223,7 +223,7 @@ nanmax['templates']['float'] = floats
 nanmax['templates']['float_None'] = floats_None
 nanmax['templates']['int'] = ints
 nanmax['templates']['int_None'] = ints_None
-nanmax['pyx_file'] = 'func/%sbit/nanmax.pyx'
+nanmax['pyx_file'] = 'func/nanmax.pyx'
 
 nanmax['main'] = '''"nanmax auto-generated from template"
 
@@ -248,8 +248,8 @@ def nanmax(arr, axis=None):
     See also
     --------
     bottleneck.nanmin: Minimum along specified axis, ignoring NaNs.
-    bottleneck.nanargmax: Indices of maximum values along axis, ignoring NaNs. 
-    
+    bottleneck.nanargmax: Indices of maximum values along axis, ignoring NaNs.
+
     Examples
     --------
     >>> bn.nanmax(1)
@@ -263,7 +263,7 @@ def nanmax(arr, axis=None):
     4.0
     >>> bn.nanmax(a, axis=0)
     array([ 1.,  4.])
-    
+
     """
     func, arr = nanmax_selector(arr, axis)
     return func(arr)
@@ -271,7 +271,7 @@ def nanmax(arr, axis=None):
 def nanmax_selector(arr, axis):
     """
     Return nanmax function and array that matches `arr` and `axis`.
-    
+
     Under the hood Bottleneck uses a separate Cython function for each
     combination of ndim, dtype, and axis. A lot of the overhead in bn.nanmax()
     is in checking that `axis` is within range, converting `arr` into an
@@ -287,7 +287,7 @@ def nanmax_selector(arr, axis):
         Input array. If `arr` is not an array, a conversion is attempted.
     axis : {int, None}
         Axis along which the maximum is to be computed.
-    
+
     Returns
     -------
     func : function
@@ -303,16 +303,16 @@ def nanmax_selector(arr, axis):
     Create a numpy array:
 
     >>> arr = np.array([1.0, 2.0, 3.0])
-    
+
     Obtain the function needed to determine the maximum of `arr` along
     axis=0:
 
     >>> func, a = bn.func.nanmax_selector(arr, axis=0)
     >>> func
     <function nanmax_1d_float64_axis0>
-    
+
     Use the returned function and array to determine the maximum:
-    
+
     >>> func(a)
     3.0
 
@@ -320,7 +320,7 @@ def nanmax_selector(arr, axis):
     cdef np.ndarray a
     if type(arr) is np.ndarray:
         a = arr
-    else:    
+    else:
         a = np.array(arr, copy=False)
     cdef int ndim = PyArray_NDIM(a)
     cdef int dtype = PyArray_TYPE(a)
