@@ -21,7 +21,7 @@ loop[1] = """\
             while b[j] != b[j]:
                 if j <= 0:
                     break
-                j -= 1    
+                j -= 1
             if i >= j:
                 flag = 0
                 break
@@ -31,8 +31,8 @@ loop[1] = """\
     n = i + flag
     k = n >> 1
     l = 0
-    r = n - 1 
-    with nogil:       
+    r = n - 1
+    with nogil:
         while l < r:
             x = b[k]
             i = l
@@ -49,7 +49,7 @@ loop[1] = """\
                 if i > j: break
             if j < k: l = i
             if k < i: r = j
-    if n % 2 == 0:        
+    if n % 2 == 0:
         amax = MINDTYPE
         allnan = 1
         for i in range(k):
@@ -57,13 +57,13 @@ loop[1] = """\
             if ai >= amax:
                 amax = ai
                 allnan = 0
-        if allnan == 0:        
+        if allnan == 0:
             return np.FLOAT(0.5 * (b[k] + amax))
         else:
             return np.FLOAT(b[k])
     else:
         return np.FLOAT(b[k])
-"""        
+"""
 loop[2] = """\
     if nINDEX1 == 0:
         PyArray_FillWithScalar(y, NAN)
@@ -76,7 +76,7 @@ loop[2] = """\
                 while b[INDEXREPLACE|j|] != b[INDEXREPLACE|j|]:
                     if j <= 0:
                         break
-                    j -= 1    
+                    j -= 1
                 if i >= j:
                     flag = 0
                     break
@@ -103,7 +103,7 @@ loop[2] = """\
                 if i > j: break
             if j < k: l = i
             if k < i: r = j
-        if n % 2 == 0:        
+        if n % 2 == 0:
             amax = MINDTYPE
             allnan = 1
             for i in range(k):
@@ -111,12 +111,12 @@ loop[2] = """\
                 if ai >= amax:
                     amax = ai
                     allnan = 0
-            if allnan == 0:        
+            if allnan == 0:
                 y[INDEXPOP] = 0.5 * (b[INDEXREPLACE|k|] + amax)
             else:
-                y[INDEXPOP] = CASTb[INDEXREPLACE|k|]         
+                y[INDEXPOP] = CASTb[INDEXREPLACE|k|]
         else:
-            y[INDEXPOP] = CASTb[INDEXREPLACE|k|]         
+            y[INDEXPOP] = CASTb[INDEXREPLACE|k|]
     return y
 """
 loop[3] = """\
@@ -132,7 +132,7 @@ loop[3] = """\
                     while b[INDEXREPLACE|j|] != b[INDEXREPLACE|j|]:
                         if j <= 0:
                             break
-                        j -= 1    
+                        j -= 1
                     if i >= j:
                         flag = 0
                         break
@@ -159,7 +159,7 @@ loop[3] = """\
                     if i > j: break
                 if j < k: l = i
                 if k < i: r = j
-            if n % 2 == 0:        
+            if n % 2 == 0:
                 amax = MINDTYPE
                 allnan = 1
                 for i in range(k):
@@ -167,12 +167,12 @@ loop[3] = """\
                     if ai >= amax:
                         amax = ai
                         allnan = 0
-                if allnan == 0:   
+                if allnan == 0:
                     y[INDEXPOP] = 0.5 * (b[INDEXREPLACE|k|] + amax)
                 else:
                     y[INDEXPOP] = CASTb[INDEXREPLACE|k|]
             else:
-                y[INDEXPOP] = CASTb[INDEXREPLACE|k|]         
+                y[INDEXPOP] = CASTb[INDEXREPLACE|k|]
     return y
 """
 
@@ -190,7 +190,7 @@ floats['top'] = """
 def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a):
     "Median of NDIMd array with dtype=DTYPE along axis=AXIS."
     cdef int allnan = 1, flag = 0
-    cdef np.npy_intp i = 0, j = 0, l, r, k, n 
+    cdef np.npy_intp i = 0, j = 0, l, r, k, n
     cdef np.DTYPE_t x, tmp, amax, ai
     cdef np.ndarray[np.DTYPE_t, ndim=NDIM] b = PyArray_Copy(a)
 """
@@ -203,7 +203,7 @@ floats['loop'][3] = loop[3].replace('CAST', '')
 # Int dtypes (not axis=None) ------------------------------------------------
 
 ints = deepcopy(floats)
-ints['dtypes'] = INT_DTYPES 
+ints['dtypes'] = INT_DTYPES
 ints['reuse_non_nan_func'] = True
 
 # Slow, unaccelerated ndim/dtype --------------------------------------------
@@ -223,13 +223,13 @@ nanmedian['slow'] = slow
 nanmedian['templates'] = {}
 nanmedian['templates']['float'] = floats
 nanmedian['templates']['int'] = ints
-nanmedian['pyx_file'] = 'func/%sbit/nanmedian.pyx'
+nanmedian['pyx_file'] = 'func/nanmedian.pyx'
 
 nanmedian['main'] = '''"nanmedian auto-generated from template"
 # Select smallest k elements code used for inner loop of median method:
 # http://projects.scipy.org/numpy/attachment/ticket/1213/quickselect.pyx
 # (C) 2009 Sturla Molden
-# SciPy license 
+# SciPy license
 #
 # From the original C function (code in public domain) in:
 #   Fast median search: an ANSI C implementation
@@ -260,16 +260,16 @@ def nanmedian(arr, axis=None):
     y : ndarray
         An array with the same shape as `arr`, except that the specified axis
         has been removed. If `arr` is a 0d array, or if axis is None, a scalar
-        is returned. `float64` return values are used for integer inputs. 
-    
+        is returned. `float64` return values are used for integer inputs.
+
     See also
     --------
-    bottleneck.median: Median along specified axis. 
+    bottleneck.median: Median along specified axis.
 
     Examples
     --------
     >>> a = np.array([[np.nan, 7, 4], [3, 2, 1]])
-    >>> a 
+    >>> a
     array([[ nan,   7.,   4.],
            [  3.,   2.,   1.]])
     >>> bn.nanmedian(a)
@@ -278,7 +278,7 @@ def nanmedian(arr, axis=None):
     array([ 3. ,  4.5,  2.5])
     >> bn.nanmedian(a, axis=1)
     array([ 5.5,  2. ])
-    
+
     """
     func, arr = nanmedian_selector(arr, axis)
     return func(arr)
@@ -286,7 +286,7 @@ def nanmedian(arr, axis=None):
 def nanmedian_selector(arr, axis):
     """
     Return nanmedian function and array that matches `arr` and `axis`.
-    
+
     Under the hood Bottleneck uses a separate Cython function for each
     combination of ndim, dtype, and axis. A lot of the overhead in
     bn.nanmedian() is in checking that `axis` is within range, converting `arr`
@@ -302,7 +302,7 @@ def nanmedian_selector(arr, axis):
         Input array. If `arr` is not an array, a conversion is attempted.
     axis : {int, None}
         Axis along which the median is to be computed.
-    
+
     Returns
     -------
     func : function
@@ -318,13 +318,13 @@ def nanmedian_selector(arr, axis):
     Create a numpy array:
 
     >>> arr = np.array([1.0, 2.0, 3.0])
-    
+
     Obtain the function needed to determine the median of `arr` along axis=0:
 
     >>> func, a = bn.func.nanmedian_selector(arr, axis=0)
     >>> func
     <function nanmedian_1d_float64_axis0>
-    
+
     Use the returned function and array to determine the median:
 
     >>> func(a)
@@ -334,7 +334,7 @@ def nanmedian_selector(arr, axis):
     cdef np.ndarray a
     if type(arr) is np.ndarray:
         a = arr
-    else:    
+    else:
         a = np.array(arr, copy=False)
     cdef tuple key
     cdef int ndim = PyArray_NDIM(a)
@@ -358,4 +358,4 @@ def nanmedian_selector(arr, axis):
             tup = (str(ndim), str(a.dtype), str(axis))
             raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
-'''   
+'''
