@@ -9,7 +9,7 @@ FLOAT_DTYPES = [x for x in bn.dtypes if 'float' in x]
 INT_DTYPES = [x for x in bn.dtypes if 'int' in x]
 
 # loops ---------------------------------------------------------------------
-    
+
 loop = {}
 loop[1] = """\
     if nINDEX0 == 0:
@@ -27,14 +27,14 @@ loop[1] = """\
                 y[INDEXREPLACE|ivec[j]|] = averank
             sumranks = 0
             dupcount = 0
-        old = new    
+        old = new
     sumranks += (nINDEX0 - 1)
-    dupcount += 1 
+    dupcount += 1
     averank = sumranks / dupcount + 1
     for j in xrange(nINDEX0 - dupcount, nINDEX0):
         y[INDEXREPLACE|ivec[j]|] = averank
     return y
-"""        
+"""
 loop[2] = """\
     if nINDEX1 == 0:
         PyArray_FillWithScalar(y, NAN)
@@ -57,7 +57,7 @@ loop[2] = """\
                     y[INDEXREPLACE|idx|] = averank
                 sumranks = 0
                 dupcount = 0
-            old = new    
+            old = new
         sumranks += (nINDEX1 - 1)
         dupcount += 1
         averank = sumranks / dupcount + 1
@@ -89,7 +89,7 @@ loop[3] = """\
                         y[INDEXREPLACE|idx|] = averank
                     sumranks = 0
                     dupcount = 0
-                old = new    
+                old = new
             sumranks += (nINDEX2 - 1)
             dupcount += 1
             averank = sumranks / dupcount + 1
@@ -111,10 +111,10 @@ floats['top'] = """
 @cython.boundscheck(False)
 @cython.wraparound(False)
 def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a):
-    "Ranks nNDIMd array with dtype=DTYPE along axis=AXIS, dealing with ties." 
-    cdef dupcount = 0
+    "Ranks nNDIMd array with dtype=DTYPE along axis=AXIS, dealing with ties."
+    cdef Py_ssize_t dupcount = 0
     cdef Py_ssize_t j, k, idx
-    cdef np.ndarray[np.intp_t, ndim=NDIM] ivec = PyArray_ArgSort(a, AXIS, NPY_QUICKSORT)
+    cdef np.ndarray[np.intp_t, ndim=NDIM] ivec = PyArray_ArgSort(a, AXIS, NPY_QUICKSORT)  # noqa
     cdef np.float64_t old, new, averank, sumranks = 0
 """
 
@@ -123,7 +123,7 @@ floats['loop'] = deepcopy(loop)
 # Int dtypes (not axis=None) ------------------------------------------------
 
 ints = deepcopy(floats)
-ints['dtypes'] = INT_DTYPES 
+ints['dtypes'] = INT_DTYPES
 ints['force_output_dtype'] = 'float64'
 ints['loop'] = deepcopy(loop)
 
@@ -144,7 +144,7 @@ rankdata['slow'] = slow
 rankdata['templates'] = {}
 rankdata['templates']['float'] = floats
 rankdata['templates']['int'] = ints
-rankdata['pyx_file'] = 'func/%sbit/rankdata.pyx'
+rankdata['pyx_file'] = 'func/rankdata.pyx'
 
 rankdata['main'] = '''"rankdata auto-generated from template"
 
@@ -168,24 +168,24 @@ def rankdata(arr, axis=None):
     -------
     y : ndarray
         An array with the same shape as `arr`. The dtype is 'float64'.
-    
+
     See also
     --------
     bottleneck.nanrankdata: Ranks the data dealing with ties and NaNs.
-    
+
     Examples
     --------
     >>> bn.rankdata([0, 2, 2, 3])
     array([ 1. ,  2.5,  2.5,  4. ])
     >>> bn.rankdata([[0, 2], [2, 3]])
     array([ 1. ,  2.5,  2.5,  4. ])
-    >>> bn.rankdata([[0, 2], [2, 3]], axis=0)     
+    >>> bn.rankdata([[0, 2], [2, 3]], axis=0)
     array([[ 1.,  1.],
            [ 2.,  2.]])
     >>> bn.rankdata([[0, 2], [2, 3]], axis=1)
     array([[ 1.,  2.],
            [ 1.,  2.]])
-    
+
     """
     func, arr = rankdata_selector(arr, axis)
     return func(arr)
@@ -193,7 +193,7 @@ def rankdata(arr, axis=None):
 def rankdata_selector(arr, axis):
     """
     Return rankdata function and array that matches `arr` and `axis`.
-    
+
     Under the hood Bottleneck uses a separate Cython function for each
     combination of ndim, dtype, and axis. A lot of the overhead in
     bn.rankdata() is in checking that `axis` is within range, converting `arr`
@@ -209,7 +209,7 @@ def rankdata_selector(arr, axis):
         Input array. If `arr` is not an array, a conversion is attempted.
     axis : {int, None}
         Axis along which to rank the elements of the array.
-    
+
     Returns
     -------
     func : function
@@ -224,13 +224,13 @@ def rankdata_selector(arr, axis):
     Create a numpy array:
 
     >>> arr = np.array([0, 2, 2, 3])
-    
+
     Obtain the function needed to rank the elements of `arr` along axis=0:
 
     >>> func, a = bn.func.rankdata_selector(arr, axis=0)
     >>> func
     <function rankdata_1d_int64_axis0>
-    
+
     Use the returned function and array:
 
     >>> func(a)
@@ -240,7 +240,7 @@ def rankdata_selector(arr, axis):
     cdef np.ndarray a
     if type(arr) is np.ndarray:
         a = arr
-    else:    
+    else:
         a = np.array(arr, copy=False)
     cdef tuple key
     cdef int ndim = PyArray_NDIM(a)
@@ -264,4 +264,4 @@ def rankdata_selector(arr, axis):
             tup = (str(ndim), str(a.dtype), str(axis))
             raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
-'''   
+'''
