@@ -35,7 +35,7 @@ loop[1] = """\
             return PyArray_Copy(a)
         else:
             return a.astype(np.float64)
-    for iINDEX0 in range(window-1):    
+    for iINDEX0 in range(window-1):
         y[INDEXALL] = np.nan
     mm = mm_new(window)
     for iINDEX0 in range(window):
@@ -46,7 +46,7 @@ loop[1] = """\
         y[INDEXALL] = mm_get_median(mm)
     mm_free(mm)
     return y
-""" 
+"""
 loop[2] = """\
     if (window < 1) or (window > nAXIS):
         raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
@@ -56,8 +56,8 @@ loop[2] = """\
         else:
             return a.astype(np.float64)
     mm = mm_new(window)
-    for iINDEX0 in range(nINDEX0):    
-        for iINDEX1 in range(window-1):    
+    for iINDEX0 in range(nINDEX0):
+        for iINDEX1 in range(window-1):
             y[INDEXALL] = np.nan
         for iINDEX1 in range(window):
             mm_insert_init(mm, a[INDEXALL])
@@ -79,9 +79,9 @@ loop[3] = """\
         else:
             return a.astype(np.float64)
     mm = mm_new(window)
-    for iINDEX0 in range(nINDEX0):    
+    for iINDEX0 in range(nINDEX0):
         for iINDEX1 in range(nINDEX1):
-            for iINDEX2 in range(window-1):    
+            for iINDEX2 in range(window-1):
                 y[INDEXALL] = np.nan
             for iINDEX2 in range(window):
                 mm_insert_init(mm, a[INDEXALL])
@@ -101,7 +101,7 @@ floats['loop'] = loop
 
 ints = deepcopy(floats)
 ints['force_output_dtype'] = 'float64'
-ints['dtypes'] = INT_DTYPES 
+ints['dtypes'] = INT_DTYPES
 
 # Slow, unaccelerated ndim/dtype --------------------------------------------
 
@@ -120,11 +120,11 @@ move_median['slow'] = slow
 move_median['templates'] = {}
 move_median['templates']['float'] = floats
 move_median['templates']['int'] = ints
-move_median['pyx_file'] = 'move/%sbit/move_median.pyx'
+move_median['pyx_file'] = 'move/move_median.pyx'
 
 move_median['main'] = '''"move_median auto-generated from template"
 
-cdef extern from "../csrc/move_median.c":
+cdef extern from "csrc/move_median.c":
     struct _mm_node:
         np.npy_uint32   small
         np.npy_uint64   idx
@@ -153,10 +153,10 @@ cdef extern from "../csrc/move_median.c":
 def move_median(arr, int window, int axis=-1):
     """
     Moving window median along the specified axis.
-    
+
     This functions is not protected against NaN. Therefore, you may get
     unexpected results if the input contains NaN.
-    
+
     Parameters
     ----------
     arr : ndarray
@@ -171,9 +171,9 @@ def move_median(arr, int window, int axis=-1):
     Returns
     -------
     y : ndarray
-        The moving median of the input array along the specified axis. The output
-        has the same shape as the input. 
-    
+        The moving median of the input array along the specified axis. The
+        output has the same shape as the input.
+
     Notes
     -----
     Unexpected results may occur if the input array contains NaN.
@@ -191,7 +191,7 @@ def move_median(arr, int window, int axis=-1):
 def move_median_selector(arr, int axis):
     """
     Return move_median function and array that matches `arr` and `axis`.
-    
+
     Under the hood Bottleneck uses a separate Cython function for each
     combination of ndim, dtype, and axis. A lot of the overhead in
     bn.move_median() is in checking that `axis` is within range, converting
@@ -223,14 +223,14 @@ def move_median_selector(arr, int axis):
     Create a numpy array:
 
     >>> arr = np.array([1.0, 2.0, 3.0, 4.0])
-    
+
     Obtain the function needed to determine the sum of `arr` along axis=0:
-    
+
     >>> window, axis = 2, 0
     >>> func, a = bn.move.move_median_selector(arr, axis)
     >>> func
     <function move_median_1d_float64_axis0>
-    
+
     Use the returned function and array to determine the moving median:
 
     >>> func(a, window)
@@ -240,7 +240,7 @@ def move_median_selector(arr, int axis):
     cdef np.ndarray a
     if type(arr) is np.ndarray:
         a = arr
-    else:    
+    else:
         a = np.array(arr, copy=False)
     cdef int ndim = PyArray_NDIM(a)
     cdef int dtype = PyArray_TYPE(a)
@@ -258,4 +258,4 @@ def move_median_selector(arr, int axis):
             tup = (str(ndim), str(a.dtype), str(axis))
             raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
-'''   
+'''
