@@ -24,7 +24,7 @@ def NAME_NDIMd_DTYPE_axisAXIS(np.ndarray[np.DTYPE_t, ndim=NDIM] a,
                                   int window, int ddof):
     "Moving std of NDIMd array of dtype=DTYPE along axis=AXIS."
     cdef Py_ssize_t count = 0
-    cdef double asum = 0, a2sum = 0, ai
+    cdef double asum = 0, a2sum = 0, ai, ssr
 """
 
 loop = {}
@@ -46,7 +46,11 @@ loop[1] = """\
         a2sum += ai * ai
         count += 1
     if count == window:
-       y[INDEXALL] = sqrt((a2sum - asum * asum / count) / (count - ddof))
+        ssr = a2sum - asum * asum / count
+        if ssr < 0:
+            y[INDEXALL] = 0
+        else:
+            y[INDEXALL] = sqrt(ssr / (count - ddof))
     else:
        y[INDEXALL] = NAN
     for iINDEX0 in range(window, nINDEX0):
@@ -61,12 +65,16 @@ loop[1] = """\
             a2sum -= ai * ai
             count -= 1
         if count == window:
-            y[INDEXALL] = sqrt((a2sum - asum * asum / count) / (count - ddof))
+            ssr = a2sum - asum * asum / count
+            if ssr < 0:
+                y[INDEXALL] = 0
+            else:
+                y[INDEXALL] = sqrt(ssr / (count - ddof))
         else:
             y[INDEXALL] = NAN
 
     return y
-"""        
+"""
 loop[2] = """\
     if (window < 1) or (window > nAXIS):
         raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
@@ -89,7 +97,11 @@ loop[2] = """\
             a2sum += ai * ai
             count += 1
         if count == window:
-           y[INDEXALL] = sqrt((a2sum - asum * asum / count) / (count - ddof))
+            ssr = a2sum - asum * asum / count
+            if ssr < 0:
+                y[INDEXALL] = 0
+            else:
+                y[INDEXALL] = sqrt(ssr / (count - ddof))
         else:
            y[INDEXALL] = NAN
         for iINDEX1 in range(window, nINDEX1):
@@ -104,8 +116,11 @@ loop[2] = """\
                 a2sum -= ai * ai
                 count -= 1
             if count == window:
-                y[INDEXALL] = sqrt((a2sum - asum * asum / count) \
-                              / (count - ddof))
+                ssr = a2sum - asum * asum / count
+                if ssr < 0:
+                    y[INDEXALL] = 0
+                else:
+                    y[INDEXALL] = sqrt(ssr / (count - ddof))
             else:
                 y[INDEXALL] = NAN
 
@@ -134,8 +149,11 @@ loop[3] = """\
                 a2sum += ai * ai
                 count += 1
             if count == window:
-               y[INDEXALL] = sqrt((a2sum - asum * asum / count) \
-                             / (count - ddof))
+                ssr = a2sum - asum * asum / count
+                if ssr < 0:
+                    y[INDEXALL] = 0
+                else:
+                    y[INDEXALL] = sqrt(ssr / (count - ddof))
             else:
                y[INDEXALL] = NAN
             for iINDEX2 in range(window, nINDEX2):
@@ -150,8 +168,11 @@ loop[3] = """\
                     a2sum -= ai * ai
                     count -= 1
                 if count == window:
-                    y[INDEXALL] = sqrt((a2sum - asum * asum / count) \
-                                  / (count - ddof))
+                    ssr = a2sum - asum * asum / count
+                    if ssr < 0:
+                        y[INDEXALL] = 0
+                    else:
+                        y[INDEXALL] = sqrt(ssr / (count - ddof))
                 else:
                     y[INDEXALL] = NAN
 
@@ -193,11 +214,11 @@ loop[1] = """\
         y[INDEXALL] = sqrt((a2sum - asum * asum / window) / winddof)
 
     return y
-"""        
+"""
 loop[2] = """\
     if (window < 1) or (window > nAXIS):
         raise ValueError(MOVE_WINDOW_ERR_MSG % (window, nAXIS))
-    
+
     winddof = window - ddof
     for iINDEX0 in range(nINDEX0):
         asum = 0
@@ -261,7 +282,7 @@ ints['loop'] = loop
 slow = {}
 slow['name'] = "move_std"
 slow['signature'] = "arr, window, ddof"
-slow['func'] = "bn.slow.move_std(arr, window, axis=AXIS, ddof=ddof)"    
+slow['func'] = "bn.slow.move_std(arr, window, axis=AXIS, ddof=ddof)"
 
 # Template ------------------------------------------------------------------
 
@@ -273,7 +294,7 @@ move_std['slow'] = slow
 move_std['templates'] = {}
 move_std['templates']['float'] = floats
 move_std['templates']['int'] = ints
-move_std['pyx_file'] = 'move/%sbit/move_std.pyx'
+move_std['pyx_file'] = 'move/move_std.pyx'
 
 move_std['main'] = '''"move_std auto-generated from template"
 
@@ -287,9 +308,9 @@ def move_std(arr, int window, int axis=-1, int ddof=0):
     An example of a one-pass algorithm:
 
         >>> np.sqrt((arr*arr).mean() - arr.mean()**2)
-    
-    An example of a two-pass algorithm:    
-    
+
+    An example of a two-pass algorithm:
+
         >>> np.sqrt(((arr - arr.mean())**2).mean())
 
     Note in the two-pass algorithm the mean must be found (first pass) before
@@ -305,12 +326,16 @@ def move_std(arr, int window, int axis=-1, int ddof=0):
         The axis over which to perform the moving standard deviation. By
         default the moving standard deviation is taken over the last axis
         (axis=-1). An axis of None is not allowed.
+    ddof : int, optional
+        Means Delta Degrees of Freedom. The divisor used in calculations
+        is ``N - ddof``, where ``N`` represents the number of elements.
+        By default `ddof` is zero.
 
     Returns
     -------
     y : ndarray
         The moving standard deviation of the input array along the specified
-        axis. The output has the same shape as the input. 
+        axis. The output has the same shape as the input.
 
     Examples
     --------
@@ -325,7 +350,7 @@ def move_std(arr, int window, int axis=-1, int ddof=0):
 def move_std_selector(arr, int axis):
     """
     Return move_std function and array that matches `arr` and `axis`.
-    
+
     Under the hood Bottleneck uses a separate Cython function for each
     combination of ndim, dtype, and axis. A lot of the overhead in
     bn.move_std() is in checking that `axis` is within range, converting
@@ -341,7 +366,7 @@ def move_std_selector(arr, int axis):
         Input array. If `arr` is not an array, a conversion is attempted.
     axis : {int, None}
         Axis along which the moving standard deviation is to be computed.
-    
+
     Returns
     -------
     func : function
@@ -358,14 +383,14 @@ def move_std_selector(arr, int axis):
     Create a numpy array:
 
     >>> arr = np.array([1.0, 2.0, 3.0, 4.0])
-    
+
     Obtain the function needed to determine the sum of `arr` along axis=0:
-    
+
     >>> window, axis = 2, 0
     >>> func, a = bn.move.move_std_selector(arr, axis)
     >>> func
     <function move_std_1d_float64_axis0>
-    
+
     Use the returned function and array to determine the moving std:
 
     >>> func(a, window)
@@ -375,7 +400,7 @@ def move_std_selector(arr, int axis):
     cdef np.ndarray a
     if type(arr) is np.ndarray:
         a = arr
-    else:    
+    else:
         a = np.array(arr, copy=False)
     cdef int ndim = PyArray_NDIM(a)
     cdef int dtype = PyArray_TYPE(a)
@@ -393,4 +418,4 @@ def move_std_selector(arr, int axis):
             tup = (str(ndim), str(a.dtype), str(axis))
             raise TypeError("Unsupported ndim/dtype/axis (%s/%s/%s)." % tup)
     return func, a
-'''   
+'''
